@@ -149,11 +149,12 @@ KDE_NO_EXPORT bool MediaInfo::wget (const String &str) {
     {
         only_playlist = true;
         mime = mrl->mimetype;
-        if (mime == "application/x-shockwave-flash" ||
-                mime == "application/futuresplash") {
+#ifdef __ARMEL__
+        if (NpPlayer::isFlashMimeType (mime)) {
             ready ();
             return true; // FIXME
         }
+#endif
     }
 
     URL uri (str);
