@@ -233,13 +233,12 @@ static void gstTag (const GstTagList *lst, const gchar *tag, gpointer data) {
             output ("ID_AUDIO_CODEC=%s;\n", val);
         } else if (!strcmp (tag, "video-codec")) {
             output ("ID_VIDEO_CODEC=%s\n", val);
-            has_video_codec = TRUE;
         } else {
             fprintf (stderr, "Tag: %s=%s\n", tag, val);
         }
         g_free (val);
     } else {
-        fprintf (stderr, "Tag: %s\n");
+        fprintf (stderr, "Tag: %s\n", tag);
     }
 }
 
@@ -290,15 +289,33 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
         case GST_MESSAGE_STATE_CHANGED: {
             GstState old_state, new_state;
             gst_message_parse_state_changed(message, &old_state, &new_state,0L);
-            if (GST_IS_ELEMENT (message->src) &&
-                    GST_ELEMENT (message->src) == gst_elm_play) {
-                if (old_state == GST_STATE_PAUSED &&
+            if (GST_IS_ELEMENT (message->src)) {
+                if (GST_ELEMENT (message->src) == gst_elm_play) {
+                    if (old_state == GST_STATE_PAUSED &&
+                            new_state >= GST_STATE_PLAYING) {
+                        gstGetDuration ();
+                        g_idle_add (cb_playing, NULL);
+                    } else if (old_state >= GST_STATE_PAUSED &&
+                            new_state <= GST_STATE_READY)
+                        g_idle_add (cb_stop, NULL);
+                } else if (old_state == GST_STATE_PAUSED &&
                         new_state >= GST_STATE_PLAYING) {
-                    gstGetDuration ();
-                    g_idle_add (cb_playing, NULL);
-                } else if (old_state >= GST_STATE_PAUSED &&
-                        new_state <= GST_STATE_READY)
-                    g_idle_add (cb_stop, NULL);
+                    gchar *name = gst_object_get_name (GST_OBJECT (message->src));
+                    fprintf (stderr, "%s changed to PLAYING\n", name);
+                    if (!has_video_codec && !strcmp (name, "videosink")) {
+                        has_video_codec = TRUE;
+                        GstPad *pad = gst_element_get_static_pad (
+                                GST_ELEMENT (message->src), "sink");
+                        if (!pad)
+                            pad = gst_element_get_request_pad (
+                                    GST_ELEMENT (message->src), "sink");
+                        if (pad) {
+                            gstCapsSet (pad, NULL, NULL);
+                            g_object_unref (G_OBJECT (pad));
+                        }
+                    }
+                    g_free (name);
+                }
             }
             break;
         }
@@ -309,6 +326,7 @@ static void gstBusMessage (GstBus *bus, GstMessage *message, gpointer data) {
         case GST_MESSAGE_CLOCK_LOST:
         case GST_MESSAGE_NEW_CLOCK:
         case GST_MESSAGE_STATE_DIRTY:
+        case GST_MESSAGE_STREAM_STATUS:
              break;
         default:
              fprintf (stderr, "Unhandled msg %s (0x%x)\n",
@@ -699,7 +717,7 @@ static gboolean cb_playing (gpointer data) {
         notified_playing = TRUE;
         if (!has_video_codec)
             output ("Video: no video\n");
-        output ("Start playback\n");
+        output ("\rA:0.0\rA:0.0");
         position_tag = g_timeout_add (500, cb_position, NULL);
         if (seek_start > 0)
             seek (seek_start * 10);
