@@ -1,6 +1,6 @@
-/* This file is part of the KDE project
+/* This file is part of the KMPlayer project
  *
- * Copyright (C) 2006 Koos Vriezen <koos.vriezen@xs4all.nl>
+ * Copyright (C) 2006 Koos Vriezen <koos.vriezen@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,8 +21,6 @@
 #ifndef _KMPLAYER_XSPF_H_
 #define _KMPLAYER_XSPF_H_
 
-#include <qstring.h>
-
 #include "kmplayerplaylist.h"
 
 namespace KMPlayer {
@@ -49,19 +47,19 @@ const short id_node_tracknum = 516;
 const short id_node_duration = 517;
 const short id_node_link = 518;
 
-class Playlist : public Mrl {
+class KMPLAYER_NO_EXPORT Playlist : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Playlist (NodePtr & d) : Mrl (d, id_node_playlist) {}
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
-    bool expose () const { return !pretty_name.isEmpty (); }
+    bool expose () const { return !title.isEmpty (); }
     void closed ();
 };
 
-class Tracklist : public Node {
+class KMPLAYER_NO_EXPORT Tracklist : public Element {
 public:
-    KDE_NO_CDTOR_EXPORT Tracklist (NodePtr & d) : Node (d, id_node_tracklist) {}
-    NodePtr childFromTag (const QString & tag);
+    KDE_NO_CDTOR_EXPORT Tracklist (NodePtr & d) : Element (d, id_node_tracklist) {}
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "tracklist"; }
     bool expose () const { return false; }
 };
@@ -71,8 +69,19 @@ public:
     KDE_NO_CDTOR_EXPORT Track (NodePtr & d) : Mrl (d, id_node_track) {}
     void closed ();
     void activate ();
+    PlayType playType ();
+    Mrl * linkNode ();
     KDE_NO_EXPORT const char * nodeName () const { return "track"; }
-    NodePtr childFromTag (const QString & tag);
+    Node *childFromTag (const String & tag);
+    NodePtrW location;
+};
+
+class KMPLAYER_NO_EXPORT Location : public Mrl {
+public:
+    KDE_NO_CDTOR_EXPORT Location (NodePtr &d) : Mrl (d, id_node_location) {}
+    KDE_NO_EXPORT const char * nodeName () const { return "location"; }
+    void closed ();
+    bool expose () const { return false; }
 };
 
 } //namespace XSPF
