@@ -147,7 +147,7 @@ void Control::init () {
     use_xvideo = true;
    //media_server = new OssoMediaServer (this, m_app->osso_context, use_xvideo);
     MPlayer *gst = new MPlayer (this, "osso-media-server");
-    gst->setPlayer ("kgstplayer");
+    gst->setPlayer ("/opt/kmplayer/bin/kgstplayer");
     gst->setAudioDriver ("pulse");
     gst->setVideoDriver ("xv");
     media_server = gst;
@@ -1193,11 +1193,6 @@ gboolean cb_mainview_delete (GtkObject *, GdkEvent *, Application *app) {
     return false;
 }
 
-void cb_mainview_close (GtkObject *, Application *app) {
-    CONTROL(app)->deinit ();
-    gtk_main_quit ();
-}
-
 static bool testFullscreenPlaylist (Application *app) {
     Control *ctr = CONTROL(app);
     return ((ctr->process () != ctr->mplayer || !ctr->process ()->hasXv ()) &&
@@ -1297,7 +1292,7 @@ locationbarGainFocus (GtkWidget *, GdkEventFocus *, Application * app) {
             "http://www.theworld.org/rss/tech.xml",
             "http://www.etherbeat.com/shoutcast/64.pls",
             "http://www.swissgroove.ch/listen.m3u",
-            "file:///home/user/MyDocs/.videos/Discovery.avi"
+            "file:///home/user/MyDocs/.videos/Nokia_N900.mp4"
         };
         int defpos = 0;
         locationbar_initialized = true;
@@ -1379,6 +1374,7 @@ void playerMenuActivate (GtkMenuItem *item, Application *app) {
         idx = ctrl->mplayer ? 2 : 1;
 #endif
     hildon_touch_selector_set_active (HILDON_TOUCH_SELECTOR (selector), 0, idx);
+    gtk_window_set_title (GTK_WINDOW (dialog), "Select Player");
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
@@ -1468,6 +1464,7 @@ void generatorMenuActivate (GtkMenuItem *item, Application *app) {
         hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
                                 txt);
     }
+    gtk_window_set_title (GTK_WINDOW (dialog), "Generate Playlist");
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
 
@@ -1509,6 +1506,7 @@ void playlistMenuActivate (GtkMenuItem *item, Application *app) {
                 "Show all XML Nodes");
         hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (selector),
                 "Edit XML");
+        gtk_window_set_title (GTK_WINDOW (dialog), "Playlist Options");
         gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
 
@@ -1531,7 +1529,7 @@ void playlistMenuActivate (GtkMenuItem *item, Application *app) {
         }
     } else {
         hildon_banner_show_information (GTK_WIDGET (app->window), NULL,
-                "No Playlist Item Selected");
+                "No playlist item selected");
     }
 }
 
