@@ -390,9 +390,7 @@ MPlayer::MPlayer (ProcessNotify *ctrl, const char *nm)
    path ("mplayer"),
    audio_driver (NULL),
    video_driver (NULL),
-   wait_for_pause (false) {
-    m_rect = IRect (434, 60, 342, 260);
-}
+   wait_for_pause (false) {}
 
 MPlayer::~MPlayer () {
 }
@@ -429,14 +427,8 @@ KMPLAYER_NO_EXPORT bool MPlayer::play (NodePtr node) {
     //else
         snprintf (buf, sizeof(buf),
                 video_driver
-                ?  video_driver
-                : has_xv
-                    ? "xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d"
-                    : "omapfb,xv,nokia770:fb_overlay_only:x=%d:y=%d:w=%d:h=%d",
-                m_rect.x() - (m_rect.x() % 2),
-                m_rect.y() - (m_rect.y() % 2),
-                m_rect.width() - (m_rect.width() % 4),
-                m_rect.height() - (m_rect.height() % 4));
+                ? video_driver
+                : "xv");
     cmdline += String (buf);
     if (audio_driver) {
         snprintf (buf, sizeof (buf), " -ao %s", audio_driver);
@@ -596,23 +588,6 @@ KMPLAYER_NO_EXPORT bool MPlayer::brightness (int pos, bool absolute) {
     return true;
 }
 
-KMPLAYER_NO_EXPORT void MPlayer::setVideoWindow (int x, int y, int w, int h) {
-    debugLog() << "setVideoWindow " << x << "," << y << " " << w << "x" << h << endl;
-    if (x + w < 0 || y + h < 0 || w <= 0 || h <= 1 /* hack !!*/ ||
-                x > 800 || y > 480 || w > 800 || h > 480)
-        return;
-    IRect rect = IRect (x, y, w, h);
-    if (rect == m_rect)
-        return;
-    m_rect = rect;
-    if (!hasVideo ())
-        return;
-    char buf[64];
-    snprintf (buf, sizeof (buf), "vo_change_rectangle %d %d %d %d",
-            x - (x % 2), y - (y % 2), w - (w % 4), h - (h % 4));
-    sendCommand (String (buf));
-}
-
 KMPLAYER_NO_EXPORT void MPlayer::processExited (UnixProcess *) {
     unix_process.closeStdOut ();
     commands.clear ();
@@ -868,6 +843,12 @@ KDE_NO_CDTOR_EXPORT NpPlayer::~NpPlayer () {
         g_free (mime);
 }
 
+bool NpPlayer::isFlashMimeType (const String &mime)
+{
+    return mime == "application/x-shockwave-flash" ||
+        mime == "application/futuresplash";
+}
+
 KMPLAYER_NO_EXPORT bool NpPlayer::ready (unsigned int viewer) {
     debugLog () << "NpPlayer::ready" << endl;
     m_viewer = viewer;
@@ -893,7 +874,6 @@ KMPLAYER_NO_EXPORT bool NpPlayer::ready (unsigned int viewer) {
 }
 
 KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
-    debugLog () << "NpPlayer::play" << endl;
     if (playing ())
         return true;
     setState (Buffering);
@@ -902,10 +882,12 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
         setState (Ready);
         return false;
     }
+    nppInstanceTopUrl (m_url);
     streams = g_tree_new (streamCompare);
 
     GTree *params = g_tree_new ((GCompareFunc)::strcmp);
     Mrl *mrl = this->mrl ();
+    debugLog () << "NpPlayer::play " << mrl->mimetype << endl;
     if (mrl->id == id_node_html_object) {
         for (Node *n = mrl->firstChild (); n; n = n->nextSibling ()) {
             /*if (n->id == KMPlayer::id_node_param) {
@@ -927,8 +909,13 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
                 }
             }
         }
+    } else if (NpPlayer::isFlashMimeType (mrl->mimetype)) {
+        g_tree_insert (params, strdup ("SRC"), strdup (m_url));
     } else {
-        g_tree_insert (params, strdup ("SRC"), strdup ((const char *) m_url));
+        String flashvars = String ("file=") + URL::encode_string (m_url);
+        m_url = "http://video.linuxfoundation.org/sites/all/modules/custom/os_video_player/mediaplayer.swf";
+        g_tree_insert (params, strdup ("SRC"), strdup (m_url));
+        g_tree_insert (params, strdup ("flashvars"), strdup (flashvars));
     }
     argc = g_tree_nnodes (params);
     argn = (char **) malloc (argc * sizeof (char *));
@@ -937,7 +924,6 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
     g_tree_traverse (params, copyParams, G_IN_ORDER, tuple);
     g_tree_destroy (params);
 
-    nppInstanceTopUrl (m_url);
     npdata = nppInstanceOpen (mime, argc, argn, argv, (void *)this, &ns_notify);
     if (!npdata) {
         g_tree_destroy (streams);
@@ -950,8 +936,10 @@ KMPLAYER_NO_EXPORT bool NpPlayer::play (NodePtr node) {
 }
 
 KMPLAYER_NO_EXPORT void NpPlayer::pluginEmbedded () {
-    nppInstanceStart ((const char *)m_url, mime, npdata);
-    setState (Playing);
+    if (state () == Buffering) {
+        nppInstanceStart ((const char *)m_url, mime, npdata);
+        setState (Playing);
+    }
 }
 
 KMPLAYER_NO_EXPORT void NpPlayer::requestStream (void *inst, uint32_t sid,
