@@ -311,12 +311,20 @@ bool GLibString::endsWith (const GLibString & suffix) const {
     return !suffix.data;
 }
 
-int GLibString::indexOf (const GLibString & needle) const {
+int GLibString::indexOf (const GLibString &needle, int offset) const {
     if (!data)
         return needle.data ? -1 : 0;
     if (!needle.data)
         return 0;
-    gchar * str = strstr (data->ptr, needle.data->ptr);
+    char *p = data->ptr;
+    if (offset > -1) {
+        if (data->buf_len < 0)
+            data->buf_len = strlen (data->ptr);
+        if (offset >= data->buf_len)
+            return -1;
+        p += offset;
+    }
+    gchar * str = strstr (p, needle.data->ptr);
     if (!str)
         return -1;
     return int (str - data->ptr);
@@ -536,14 +544,17 @@ KMPLAYER_NO_EXPORT off_t GIOFile::writeBlock (const char * data, off_t length) {
 //-----------------------------------------------------------------------------
 
 GioUrl::GioUrl (const GioUrl &base, const String &rel) {
-    if (base.m_file) {
+    GFile *file = g_file_new_for_uri ((const char *) rel);
+    gchar *scheme = g_file_get_uri_scheme (file);
+    if (base.m_file && (!scheme || !scheme[0])) {
         GFile *p = g_file_get_parent (base.m_file);
         m_file = g_file_resolve_relative_path (p ? p : base.m_file, rel);
         if (p)
             g_object_unref (p);
     } else {
-        m_file = g_file_new_for_uri ((const char *) rel);
+        m_file = file;
     }
+    g_free (scheme);
 }
 
 KMPLAYER_NO_CDTOR_EXPORT GioUrl::GioUrl (const String &url) : m_file (NULL) {
@@ -591,15 +602,23 @@ GioUrl & GioUrl::operator = (const GioUrl & url) {
 }
 
 KMPLAYER_NO_EXPORT String GioUrl::path () const {
-    if (m_file)
-        return String (g_file_get_path (m_file));
-    return String ();
+    String str;
+    if (m_file) {
+        char *p = g_file_get_path (m_file);
+        if (p)
+            str.take (p);
+    }
+    return str;
 }
 
 KMPLAYER_NO_EXPORT String GioUrl::protocol () const {
-    if (m_file)
-        return String (g_file_get_uri_scheme (m_file));
-    return String ();
+    String str;
+    if (m_file) {
+        char *scheme = g_file_get_uri_scheme (m_file);
+        if (scheme)
+            str.take (scheme);
+    }
+    return str;
 }
 
 KMPLAYER_NO_EXPORT String GioUrl::decode_string (const String & s) {
