@@ -308,7 +308,7 @@ public:
     static GLibString number (double nr);
     bool startsWith (const GLibString & prefix) const;
     bool endsWith (const GLibString & suffix) const;
-    int indexOf (const GLibString & needle) const;
+    int indexOf (const GLibString &needle, int offset=-1) const;
     int lastIndexOf (const GLibString & needle) const;
     GLibString replace (Char c1, Char c2) const;
     bool isEmpty () const;
