@@ -397,6 +397,7 @@ TrieString StringPool::attr_type;
 TrieString StringPool::attr_value;
 TrieString StringPool::attr_fill;
 TrieString StringPool::attr_fit;
+TrieString StringPool::attr_panzoom;
 
 void StringPool::init() {
     attr_width = "width";
@@ -420,6 +421,7 @@ void StringPool::init() {
     attr_dur = "dur";
     attr_bottom = "bottom";
     attr_begin = "begin";
+    attr_panzoom = "panZoom";
 }
 
 void StringPool::reset() {
@@ -444,6 +446,7 @@ void StringPool::reset() {
     attr_value.clear ();
     attr_fill.clear ();
     attr_fit.clear ();
+    attr_panzoom.clear ();
     if (root_trie->first_child) {
         warningLog () << "Trie not empty" << endl;
         dumpTrie ();
